<?php
namespace KissGridHoverMotion\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;

/**
 * Elementor
 *
 * Elementor widget
 *
 * @since 1.0.0
 */
class kiss__grid_hover_motion2 extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'grid-hover-motion2';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Grid Hover Motion #2', 'grid-hover-motion' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-drag-n-drop';
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [  'gsap' , 'imagesloaded' , 'kiss-grid-hover-motion2' ];
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kiss-grid-hover-motion-category' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'section_content0',
			[
				'label' => esc_html__( 'Color', 'grid-hover-motion' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'style',
			array(
			  'label'       => esc_html__('Text Color', 'grid-hover-motion'),
			  'type'        => \Elementor\Controls_Manager::SELECT,
			  'default'     => 'dark',
			  'label_block' => true,
			  'options' => array(
				'light' => esc_html__('Light', 'grid-hover-motion'),
				'dark' => esc_html__('Dark', 'grid-hover-motion'),
			  )
			)
		  );
	 
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'grid-hover-motion' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'grid-hover-motion' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Are you ready?', 'grid-hover-motion' ),
				'placeholder' => esc_html__( 'Type your content here', 'grid-hover-motion' ),
			]
		);
		
		$this->add_control(
			'subtitle',
			[
				'label' => esc_html__( 'Subitle', 'grid-hover-motion' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '', 'grid-hover-motion' ),
				'placeholder' => esc_html__( 'Type your content here', 'grid-hover-motion' ),
			]
		);
				
		$this->add_control(
			'gallery',
			[
				'label' => esc_html__( 'Items', 'on-scroll-3d' ),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'show_label' => true,
				'description' => esc_html__( 'Up to 10 images', 'grid-hover-motion' ),
			]
		);
	
		$this->end_controls_section();
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$style    = $settings['style'];
		
	?>
	<section class="grid--hover--motion <?php echo esc_html($settings['style']); ?>">
		<div class="grid-hover-motion-content">
			<div class="grid-hover-motion">
				<?php $i = 1; foreach ( $settings['gallery'] as $image ) {
				echo '<div class="grid-hover-motion__item pos-' .$i .'"><div class="grid-hover-motion__item-img" style="background-image:url(' .($image['url']) . ')"></div></div>';
				$i++; } ?>
			</div>
			<h2 class="content__title no-select">
				<span><?php echo esc_html($settings['title']); ?></span>
				<span class="content__title-sub"><?php echo esc_html($settings['subtitle']); ?></span>
			</h2>
		</div>
	</section>
<?php			
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function content_template() {}
	
}
